
from textwrap import dedent

from jinsung.ha import Me


me = Me()
about_me = dedent(
    """
    Born on the 29th of September, 1994 in Seoul, South Korea. The only child.
    Met StarCraft I and Diablo II when I was 7. Love playing games since then.
    Skipped the first day of elementary school for playing StarCraft: Brood War.
    Middle school, a friend of mine who was a server operator, got me interested in programming.
    High school, a teacher asked me what I want to do for a living. Had no idea. 
    Knew that I love sitting in front of a computer, even when I'm not playing games.
    Decided to learn computer science, preferably far from home where all distractions belong to.
    Went to the United Kingdom for studying GCE Advanced Level, Chose to study Maths, Physics and Chemistry. Loved Maths.
    Got accepted to Imperial College London which is 2nd best university in the world, according to QS world university rankings 2014.
    Majored in computer science, specialised in AI, from 2014 to 2019. The hardest time in my life.
    Graduated from the college, my country called me for duty. Decided to fulfil the duty as technical research personnel(전문연구요원).
    Started working as a backend software engineer in AI team, for LUXROBO, a modular robotics startup.
    Pursuing my career in machine learning, as a backend software engineer.
    """.rstrip()
)
print(about_me)



from typing import List
from typing import Tuple


class Me:

    def __init__(self):
        print('About Me - Jinsung Ha')

    @property
    def education(self) -> str:
        degree: str = 'MEng Computing (Artificial Intelligence)'
        where: str = 'Imperial College London'
        when: str = '10.2014 - 06.2019'
        return ' | '.join([degree, where, when])

    @property
    def workspace(self) -> Tuple[str, str]:
        company: str = 'LUXROBO'
        position: str = 'Backend Software Engineer'
        return company, position

    @property
    def code(self) -> List[str]:
        return [
            'Python', 'Java', 'C', 'C++', 'Bash'
        ]



from os import path

from setuptools import setup, find_packages


def get_readme():
    here = path.abspath(path.dirname(__file__))
    with open(path.join(here, 'README.md'), encoding='utf-8') as readme_file:
        readme = readme_file.read()
        return readme


setup(
    name='jinsung',
    version='0.2.0',
    author='Jinsung Ha',
    author_email='jsung5381@naver.com',
    description='Who is Jinsung Ha?',
    long_description='Who is Jinsung Ha? \n' + get_readme(),
    long_description_content_type='text/markdown',
    license='MIT',
    url='https://github.com/jha929/jha929',
    packages=find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
)
